"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.ShikiProvider = ShikiProvider;
exports.useShiki = useShiki;
var _core = require("@shikijs/core");
var _engineJavascript = require("@shikijs/engine-javascript");
var _react = require("react");
var _jsxRuntime = require("react/jsx-runtime");
/* eslint-disable no-console */

const DEBUG = true;
function _log(...args) {
  if (DEBUG) console.log('[ShikiProvider]', ...args);
}
const ShikiContext = /*#__PURE__*/(0, _react.createContext)(null);
function ShikiProvider({
  children,
  initialLanguages,
  initialThemes
}) {
  const [highlighter, setHighlighter] = (0, _react.useState)(null);
  const [isReady, setIsReady] = (0, _react.useState)(false);
  const [error, setError] = (0, _react.useState)(null);
  (0, _react.useEffect)(() => {
    const initHighlighter = async () => {
      try {
        const highlighterInstance = await (0, _core.createHighlighterCore)({
          engine: (0, _engineJavascript.createJavaScriptRegexEngine)()
        });

        // Fallback for the first theme if specific theme access is required
        const activeTheme = initialThemes[0];

        // Test code tokenization with the dynamically set theme
        const testCode = `
          // This is a comment
          function test() {
            const str = "hello";
            return str;
          }
        `;
        const testTokens = highlighterInstance.codeToTokens(testCode.trim(), {
          lang: 'typescript',
          theme: activeTheme,
          includeExplanation: true
        });
        _log('Test tokenization:', {
          tokens: testTokens.tokens[0]?.map(token => ({
            content: token.content,
            color: token.color,
            scopes: token.explanation?.[0]?.scopes.map(s => s.scopeName),
            matches: token.explanation?.[0]?.scopes.flatMap(s => s.themeMatches || []).map(m => ({
              scope: m.scope,
              color: m.settings.foreground
            }))
          })),
          theme: highlighterInstance.getTheme(activeTheme)
        });
        setHighlighter(highlighterInstance);
        setIsReady(true);
        setError(null);
      } catch (err) {
        console.error('Highlighter initialization failed:', err);
        setError(err instanceof Error ? err : new Error('Initialization failed'));
        setIsReady(false);
      }
    };
    initHighlighter();
  }, [initialLanguages, initialThemes]);
  const value = (0, _react.useMemo)(() => ({
    highlighter,
    isReady,
    error
  }), [highlighter, isReady, error]);
  return /*#__PURE__*/(0, _jsxRuntime.jsx)(ShikiContext.Provider, {
    value: value,
    children: children
  });
}
function useShiki() {
  const context = (0, _react.useContext)(ShikiContext);
  if (!context) {
    throw new Error('useShiki must be used within a ShikiProvider');
  }
  return context;
}
//# sourceMappingURL=SyntaxContext.js.map