"use strict";

/* eslint-disable no-console */

import { createHighlighterCore } from '@shikijs/core';
import { createJavaScriptRegexEngine } from '@shikijs/engine-javascript';
import { createContext, useContext, useEffect, useMemo, useState } from 'react';
import { jsx as _jsx } from "react/jsx-runtime";
const DEBUG = true;
function _log(...args) {
  if (DEBUG) console.log('[ShikiProvider]', ...args);
}
const ShikiContext = /*#__PURE__*/createContext(null);
export function ShikiProvider({
  children,
  initialLanguages,
  initialThemes
}) {
  const [highlighter, setHighlighter] = useState(null);
  const [isReady, setIsReady] = useState(false);
  const [error, setError] = useState(null);
  useEffect(() => {
    const initHighlighter = async () => {
      try {
        const highlighterInstance = await createHighlighterCore({
          engine: createJavaScriptRegexEngine()
        });

        // Fallback for the first theme if specific theme access is required
        const activeTheme = initialThemes[0];

        // Test code tokenization with the dynamically set theme
        const testCode = `
          // This is a comment
          function test() {
            const str = "hello";
            return str;
          }
        `;
        const testTokens = highlighterInstance.codeToTokens(testCode.trim(), {
          lang: 'typescript',
          theme: activeTheme,
          includeExplanation: true
        });
        _log('Test tokenization:', {
          tokens: testTokens.tokens[0]?.map(token => ({
            content: token.content,
            color: token.color,
            scopes: token.explanation?.[0]?.scopes.map(s => s.scopeName),
            matches: token.explanation?.[0]?.scopes.flatMap(s => s.themeMatches || []).map(m => ({
              scope: m.scope,
              color: m.settings.foreground
            }))
          })),
          theme: highlighterInstance.getTheme(activeTheme)
        });
        setHighlighter(highlighterInstance);
        setIsReady(true);
        setError(null);
      } catch (err) {
        console.error('Highlighter initialization failed:', err);
        setError(err instanceof Error ? err : new Error('Initialization failed'));
        setIsReady(false);
      }
    };
    initHighlighter();
  }, [initialLanguages, initialThemes]);
  const value = useMemo(() => ({
    highlighter,
    isReady,
    error
  }), [highlighter, isReady, error]);
  return /*#__PURE__*/_jsx(ShikiContext.Provider, {
    value: value,
    children: children
  });
}
export function useShiki() {
  const context = useContext(ShikiContext);
  if (!context) {
    throw new Error('useShiki must be used within a ShikiProvider');
  }
  return context;
}
//# sourceMappingURL=SyntaxContext.js.map